#!/bin/bash
#
# Build file for cpufreq
# Author: Mark Colclough
# 14 June 2008

# source http://www.cm.ph.bham.ac.uk/software/source/cpufreq-0.9.tar.gz
srcname='cpufreq'
srcversion='0.9'
srcextn='tar.gz'
tarball=$srcname-$srcversion.$srcextn
srcdir=$srcname-$srcversion
srcurl="http://www.cm.ph.bham.ac.uk/software/source/$tarball"

pkgversion='54.1'
arch='noarch'
package="$srcname-$srcversion-$arch-$pkgversion"

#       |-----handy-ruler------------------------------------------------------|
descfile="\
$srcname: $srcname (CPU frequency control)
$srcname:
$srcname: This package provides a simple startup script that enables
$srcname: kernel-based CPU speed control, to reduce power usage and
$srcname: CPU temperature.  It is fully configurable via the rc.cpufreq.conf
$srcname: file.
$srcname:
$srcname: 
$srcname: 
$srcname:
$srcname:
"

builddir=$(pwd)
src="$builddir/$srcdir"
dest="$builddir/$package"
buildlog="$builddir/$srcname-buildlog"

INS644="install -o root -g root -m 644"
INS755="install -o root -g root -m 755"
(
rm -f $buildlog
echo "==== Building package $package in directory $builddir ===="
echo "== preparing dest tree at $dest =="
rm -rf $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$srcname-$srcversion
mkdir -p $dest/usr/src/$srcname-$srcversion
mkdir -p $dest/etc/rc.d/desc.d
echo "$descfile" > $dest/install/slack-desc
$INS755 build-$srcname.sh $dest/usr/src/$srcname-$srcversion/

cd $builddir
echo "== preparing source tree at $srcdir =="
rm -rf $srcdir
tar xfz $tarball
cd $srcdir

echo "== installing =="
$INS644 README $dest/usr/doc/$srcname-$srcversion
$INS644 rc.cpufreq.conf.new $dest/etc/rc.d/
$INS644 rc.cpufreq $dest/etc/rc.d/
$INS644 cpufreq.txt $dest/etc/rc.d/desc.d/

echo "== protect existing conf file =="
cat << "EOF" > $dest/install/doinst.sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

config etc/rc.d/rc.cpufreq.conf.new
EOF

echo "== make package =="
cd $dest
makepkg -l y -c n $dest.tgz
cd $builddir
md5sum $package.tgz >$package.md5

echo "== verifying package =="
cd $builddir
zen_pkgcheck.pl $dest.tgz

echo "==== all done ===="
) 2>&1 | tee $buildlog 
